@@ -115,7 +115,9 @@ pub fn branch_new(repo_name: &str, branch_name: &str) {
         fail!("couldn't fetch origin!");
     }
 
-    let branch = repo.find_branch("main", git2::BranchType::Local).unwrap();
+    let branch = repo
+        .find_branch(&repo_config.main_branch, git2::BranchType::Local)
+        .unwrap();
     let reference = branch.into_reference();
     let commit = reference.peel_to_commit().unwrap();
 
@@ -249,11 +251,18 @@ pub fn merge_base(branch1: &str, branch2: &str) -> String {
     out.trim().to_owned()
 }
 
-pub fn diff() {
+pub fn diff(args: &[String]) {
     let (repo_config, branch_config) = conf::get_current_dir_configs();
     let base = merge_base(&branch_config.branch_name, &repo_config.main_branch);
 
-    let (_, result) = cmd::system("git", &["diff", &base], None, true);
+    let result = if args.len() > 0 {
+        let (_, result) = cmd::system("git", &["diff", &base, &args[0]], None, true);
+        result
+    } else {
+        let (_, result) = cmd::system("git", &["diff", &base], None, true);
+        result
+    };
+
     if result.is_err() {
         fail!("unable to get diff!");
     }
@@ -447,6 +456,8 @@ pub fn upload() {
         .collect::<Vec<_>>()
         .join("\n");
 
+    let body = format_description(&body);
+
     let (out, result) = cmd::system(
         "gh",
         &[
@@ -741,3 +752,73 @@ pub fn check() {
         fail!();
     }
 }
+
+fn format_description(input: &str) -> String {
+    let mut output = String::new();
+    let mut prev_text = false;
+    for line in input.lines().map(|l| l.trim()) {
+        if line.starts_with(char::is_numeric) || line.starts_with('-') || line.starts_with('[') {
+            output.push_str(&line);
+            output.push('\n');
+        } else if line.is_empty() {
+            if prev_text {
+                output.push('\n');
+            }
+            output.push('\n');
+            prev_text = false;
+        } else {
+            if prev_text {
+                output.push(' ');
+            }
+            output.push_str(line);
+            prev_text = true;
+        }
+    }
+
+    output
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_pr_description() {
+        let description = "
+
+        First line
+
+        Second line which contains a lot more content split into multiple
+        lines which are supposed to be joined together into a single continuous
+        line.
+
+        More content.
+        "
+        .trim();
+
+        let expected = "First line\n\nSecond line which contains a lot more content split into multiple lines which are supposed to be joined together into a single continuous line.\n\nMore content.";
+        assert_eq!(format_description(description), expected);
+    }
+
+    #[test]
+    fn test_pr_description_with_bullets() {
+        let description = "
+
+        First line
+
+        1. Content
+        2. another point
+        3. something else
+
+        - bullet
+        - bullet
+
+        More content.
+        "
+        .trim();
+
+        let expected =
+            "First line\n\n1. Content\n2. another point\n3. something else\n\n- bullet\n- bullet\n\nMore content.";
+        assert_eq!(format_description(description), expected);
+    }
+}
